import * as react_jsx_runtime from 'react/jsx-runtime';
import { Session } from 'next-auth';
import { PropsWithChildren } from 'react';
import * as wagmi from 'wagmi';
import { WagmiProviderProps } from 'wagmi';
import * as viem_experimental from 'viem/experimental';
import * as abitype from 'abitype';
import { Address } from 'abitype';
import * as viem from 'viem';
import { Chain, Account, RpcSchema, Prettify, PublicClientConfig, HttpTransport, HttpTransportConfig, TransportConfig } from 'viem';
import { createWeb3Modal } from '@web3modal/wagmi/react';
import { defaultWagmiConfig } from '@web3modal/wagmi/react/config';
import { GraphQLClient } from 'graphql-request';
import createClient from 'openapi-fetch';

type WagmiProps = {
    wagmiConfig: WagmiProviderProps["config"];
    initialState: WagmiProviderProps["initialState"];
};

interface SettleMintProviderProps extends PropsWithChildren, WagmiProps {
    session: Session | null;
}
/**
 * SettleMintProvider component that wraps the application with various providers.
 *
 * This component combines SessionProvider, ThemeWrapper, WagmiWrapper, and ReactQueryWrapper
 * to provide authentication, theming, Ethereum interactions, and data fetching capabilities.
 *
 * @param props - The properties for the SettleMintProvider.
 * @param props.children - The child components to be wrapped.
 * @param props.wagmiConfig - The configuration object for Wagmi.
 * @param props.initialState - The initial state for Wagmi.
 * @param props.session - The session object for authentication.
 * @returns The wrapped application components.
 *
 * @example
 * ```tsx
 * <SettleMintProvider
 *   wagmiConfig={wagmiConfig}
 *   initialState={initialState}
 *   session={session}
 * >
 *   <YourApp />
 * </SettleMintProvider>
 * ```
 */
declare function SettleMintProvider({ children, wagmiConfig, initialState, session }: SettleMintProviderProps): react_jsx_runtime.JSX.Element;

/**
 * Configuration type for Viem clients.
 *
 * @template TChain - The chain type
 * @template TAccount - The account type (optional)
 * @template TRpcSchema - The RPC schema type (optional)
 */
type ViemConfig<TChain extends Chain = Chain, TAccount extends Account | Address | undefined = undefined, TRpcSchema extends RpcSchema | undefined = undefined> = Prettify<Omit<PublicClientConfig<HttpTransport, TChain, TAccount, TRpcSchema>, "chain" | "transport"> & {
    transportConfig?: HttpTransportConfig;
    chain: TChain;
}>;
/**
 * Creates a Viem public client for interacting with the blockchain.
 *
 * @template TChain - The chain type
 * @template TAccount - The account type (optional)
 * @template TRpcSchema - The RPC schema type (optional)
 * @param parameters - Configuration parameters for the public client
 * @returns A public client instance for making blockchain requests
 * @throws {Error} If NEXT_PUBLIC_SETTLEMINT_APP_URL is not defined in the environment
 *
 * @example
 * ```typescript
 * const publicClient = createViemPublicClient({
 *   chain: mainnet,
 *   transportConfig: { timeout: 30000 }
 * });
 * ```
 */
declare function createViemPublicClient<TChain extends Chain, TAccount extends Account | Address | undefined = undefined, TRpcSchema extends RpcSchema | undefined = undefined>(parameters: ViemConfig<TChain, TAccount, TRpcSchema>): {
    account: undefined;
    batch?: viem.ClientConfig["batch"] | undefined;
    cacheTime: number;
    ccipRead?: viem.ClientConfig["ccipRead"] | undefined;
    chain: TChain;
    key: string;
    name: string;
    pollingInterval: number;
    request: viem.EIP1193RequestFn<(TRpcSchema extends RpcSchema ? [{
        Method: "web3_clientVersion";
        Parameters?: undefined;
        ReturnType: string;
    }, {
        Method: "web3_sha3";
        Parameters: [data: viem.Hash];
        ReturnType: string;
    }, {
        Method: "net_listening";
        Parameters?: undefined;
        ReturnType: boolean;
    }, {
        Method: "net_peerCount";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "net_version";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_blobBaseFee";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_blockNumber";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_call";
        Parameters: [transaction: viem.ExactPartial<viem.RpcTransactionRequest>] | [transaction: viem.ExactPartial<viem.RpcTransactionRequest>, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier] | [transaction: viem.ExactPartial<viem.RpcTransactionRequest>, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier, stateOverrideSet: viem.RpcStateOverride];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_chainId";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_coinbase";
        Parameters?: undefined;
        ReturnType: Address;
    }, {
        Method: "eth_estimateGas";
        Parameters: [transaction: viem.RpcTransactionRequest] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag, stateOverride: viem.RpcStateOverride];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_feeHistory";
        Parameters: [blockCount: viem.Quantity, newestBlock: viem.RpcBlockNumber | viem.BlockTag, rewardPercentiles: number[] | undefined];
        ReturnType: viem.RpcFeeHistory;
    }, {
        Method: "eth_gasPrice";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBalance";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBlockByHash";
        Parameters: [hash: viem.Hash, includeTransactionObjects: boolean];
        ReturnType: viem.RpcBlock | null;
    }, {
        Method: "eth_getBlockByNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, includeTransactionObjects: boolean];
        ReturnType: viem.RpcBlock | null;
    }, {
        Method: "eth_getBlockTransactionCountByHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBlockTransactionCountByNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getCode";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_getFilterChanges";
        Parameters: [filterId: viem.Quantity];
        ReturnType: viem.RpcLog[] | viem.Hex[];
    }, {
        Method: "eth_getFilterLogs";
        Parameters: [filterId: viem.Quantity];
        ReturnType: viem.RpcLog[];
    }, {
        Method: "eth_getLogs";
        Parameters: [{
            address?: Address | Address[] | undefined;
            topics?: viem.LogTopic[] | undefined;
        } & ({
            fromBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            toBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            blockHash?: undefined;
        } | {
            fromBlock?: undefined;
            toBlock?: undefined;
            blockHash?: viem.Hash | undefined;
        })];
        ReturnType: viem.RpcLog[];
    }, {
        Method: "eth_getProof";
        Parameters: [address: Address, storageKeys: viem.Hash[], block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.RpcProof;
    }, {
        Method: "eth_getStorageAt";
        Parameters: [address: Address, index: viem.Quantity, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_getTransactionByBlockHashAndIndex";
        Parameters: [hash: viem.Hash, index: viem.Quantity];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionByBlockNumberAndIndex";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, index: viem.Quantity];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionByHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionCount";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getTransactionReceipt";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcTransactionReceipt | null;
    }, {
        Method: "eth_getUncleByBlockHashAndIndex";
        Parameters: [hash: viem.Hash, index: viem.Quantity];
        ReturnType: viem.RpcUncle | null;
    }, {
        Method: "eth_getUncleByBlockNumberAndIndex";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, index: viem.Quantity];
        ReturnType: viem.RpcUncle | null;
    }, {
        Method: "eth_getUncleCountByBlockHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getUncleCountByBlockNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_maxPriorityFeePerGas";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newBlockFilter";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newFilter";
        Parameters: [filter: {
            fromBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            toBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            address?: Address | Address[] | undefined;
            topics?: viem.LogTopic[] | undefined;
        }];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newPendingTransactionFilter";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_protocolVersion";
        Parameters?: undefined;
        ReturnType: string;
    }, {
        Method: "eth_sendRawTransaction";
        Parameters: [signedTransaction: viem.Hex];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_uninstallFilter";
        Parameters: [filterId: viem.Quantity];
        ReturnType: boolean;
    }, ...TRpcSchema] : viem.PublicRpcSchema) extends infer T ? T extends (TRpcSchema extends RpcSchema ? [{
        Method: "web3_clientVersion";
        Parameters?: undefined;
        ReturnType: string;
    }, {
        Method: "web3_sha3";
        Parameters: [data: viem.Hash];
        ReturnType: string;
    }, {
        Method: "net_listening";
        Parameters?: undefined;
        ReturnType: boolean;
    }, {
        Method: "net_peerCount";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "net_version";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_blobBaseFee";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_blockNumber";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_call";
        Parameters: [transaction: viem.ExactPartial<viem.RpcTransactionRequest>] | [transaction: viem.ExactPartial<viem.RpcTransactionRequest>, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier] | [transaction: viem.ExactPartial<viem.RpcTransactionRequest>, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier, stateOverrideSet: viem.RpcStateOverride];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_chainId";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_coinbase";
        Parameters?: undefined;
        ReturnType: Address;
    }, {
        Method: "eth_estimateGas";
        Parameters: [transaction: viem.RpcTransactionRequest] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag, stateOverride: viem.RpcStateOverride];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_feeHistory";
        Parameters: [blockCount: viem.Quantity, newestBlock: viem.RpcBlockNumber | viem.BlockTag, rewardPercentiles: number[] | undefined];
        ReturnType: viem.RpcFeeHistory;
    }, {
        Method: "eth_gasPrice";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBalance";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBlockByHash";
        Parameters: [hash: viem.Hash, includeTransactionObjects: boolean];
        ReturnType: viem.RpcBlock | null;
    }, {
        Method: "eth_getBlockByNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, includeTransactionObjects: boolean];
        ReturnType: viem.RpcBlock | null;
    }, {
        Method: "eth_getBlockTransactionCountByHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBlockTransactionCountByNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getCode";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_getFilterChanges";
        Parameters: [filterId: viem.Quantity];
        ReturnType: viem.RpcLog[] | viem.Hex[];
    }, {
        Method: "eth_getFilterLogs";
        Parameters: [filterId: viem.Quantity];
        ReturnType: viem.RpcLog[];
    }, {
        Method: "eth_getLogs";
        Parameters: [{
            address?: Address | Address[] | undefined;
            topics?: viem.LogTopic[] | undefined;
        } & ({
            fromBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            toBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            blockHash?: undefined;
        } | {
            fromBlock?: undefined;
            toBlock?: undefined;
            blockHash?: viem.Hash | undefined;
        })];
        ReturnType: viem.RpcLog[];
    }, {
        Method: "eth_getProof";
        Parameters: [address: Address, storageKeys: viem.Hash[], block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.RpcProof;
    }, {
        Method: "eth_getStorageAt";
        Parameters: [address: Address, index: viem.Quantity, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_getTransactionByBlockHashAndIndex";
        Parameters: [hash: viem.Hash, index: viem.Quantity];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionByBlockNumberAndIndex";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, index: viem.Quantity];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionByHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionCount";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getTransactionReceipt";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcTransactionReceipt | null;
    }, {
        Method: "eth_getUncleByBlockHashAndIndex";
        Parameters: [hash: viem.Hash, index: viem.Quantity];
        ReturnType: viem.RpcUncle | null;
    }, {
        Method: "eth_getUncleByBlockNumberAndIndex";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, index: viem.Quantity];
        ReturnType: viem.RpcUncle | null;
    }, {
        Method: "eth_getUncleCountByBlockHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getUncleCountByBlockNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_maxPriorityFeePerGas";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newBlockFilter";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newFilter";
        Parameters: [filter: {
            fromBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            toBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            address?: Address | Address[] | undefined;
            topics?: viem.LogTopic[] | undefined;
        }];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newPendingTransactionFilter";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_protocolVersion";
        Parameters?: undefined;
        ReturnType: string;
    }, {
        Method: "eth_sendRawTransaction";
        Parameters: [signedTransaction: viem.Hex];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_uninstallFilter";
        Parameters: [filterId: viem.Quantity];
        ReturnType: boolean;
    }, ...TRpcSchema] : viem.PublicRpcSchema) ? T extends undefined ? [{
        Method: "web3_clientVersion";
        Parameters?: undefined;
        ReturnType: string;
    }, {
        Method: "web3_sha3";
        Parameters: [data: viem.Hash];
        ReturnType: string;
    }, {
        Method: "net_listening";
        Parameters?: undefined;
        ReturnType: boolean;
    }, {
        Method: "net_peerCount";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "net_version";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_blobBaseFee";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_blockNumber";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_call";
        Parameters: [transaction: viem.ExactPartial<viem.RpcTransactionRequest>] | [transaction: viem.ExactPartial<viem.RpcTransactionRequest>, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier] | [transaction: viem.ExactPartial<viem.RpcTransactionRequest>, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier, stateOverrideSet: viem.RpcStateOverride];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_chainId";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_coinbase";
        Parameters?: undefined;
        ReturnType: Address;
    }, {
        Method: "eth_estimateGas";
        Parameters: [transaction: viem.RpcTransactionRequest] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag, stateOverride: viem.RpcStateOverride];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_feeHistory";
        Parameters: [blockCount: viem.Quantity, newestBlock: viem.RpcBlockNumber | viem.BlockTag, rewardPercentiles: number[] | undefined];
        ReturnType: viem.RpcFeeHistory;
    }, {
        Method: "eth_gasPrice";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBalance";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBlockByHash";
        Parameters: [hash: viem.Hash, includeTransactionObjects: boolean];
        ReturnType: viem.RpcBlock | null;
    }, {
        Method: "eth_getBlockByNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, includeTransactionObjects: boolean];
        ReturnType: viem.RpcBlock | null;
    }, {
        Method: "eth_getBlockTransactionCountByHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBlockTransactionCountByNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getCode";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_getFilterChanges";
        Parameters: [filterId: viem.Quantity];
        ReturnType: viem.RpcLog[] | viem.Hex[];
    }, {
        Method: "eth_getFilterLogs";
        Parameters: [filterId: viem.Quantity];
        ReturnType: viem.RpcLog[];
    }, {
        Method: "eth_getLogs";
        Parameters: [{
            address?: Address | Address[] | undefined;
            topics?: viem.LogTopic[] | undefined;
        } & ({
            fromBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            toBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            blockHash?: undefined;
        } | {
            fromBlock?: undefined;
            toBlock?: undefined;
            blockHash?: viem.Hash | undefined;
        })];
        ReturnType: viem.RpcLog[];
    }, {
        Method: "eth_getProof";
        Parameters: [address: Address, storageKeys: viem.Hash[], block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.RpcProof;
    }, {
        Method: "eth_getStorageAt";
        Parameters: [address: Address, index: viem.Quantity, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_getTransactionByBlockHashAndIndex";
        Parameters: [hash: viem.Hash, index: viem.Quantity];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionByBlockNumberAndIndex";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, index: viem.Quantity];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionByHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionCount";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getTransactionReceipt";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcTransactionReceipt | null;
    }, {
        Method: "eth_getUncleByBlockHashAndIndex";
        Parameters: [hash: viem.Hash, index: viem.Quantity];
        ReturnType: viem.RpcUncle | null;
    }, {
        Method: "eth_getUncleByBlockNumberAndIndex";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, index: viem.Quantity];
        ReturnType: viem.RpcUncle | null;
    }, {
        Method: "eth_getUncleCountByBlockHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getUncleCountByBlockNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_maxPriorityFeePerGas";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newBlockFilter";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newFilter";
        Parameters: [filter: {
            fromBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            toBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            address?: Address | Address[] | undefined;
            topics?: viem.LogTopic[] | undefined;
        }];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newPendingTransactionFilter";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_protocolVersion";
        Parameters?: undefined;
        ReturnType: string;
    }, {
        Method: "eth_sendRawTransaction";
        Parameters: [signedTransaction: viem.Hex];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_uninstallFilter";
        Parameters: [filterId: viem.Quantity];
        ReturnType: boolean;
    }, {
        Method: "eth_accounts";
        Parameters?: undefined;
        ReturnType: Address[];
    }, {
        Method: "eth_chainId";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_estimateGas";
        Parameters: [transaction: viem.RpcTransactionRequest] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag, stateOverride: viem.RpcStateOverride];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_requestAccounts";
        Parameters?: undefined;
        ReturnType: Address[];
    }, {
        Method: "eth_sendTransaction";
        Parameters: [transaction: viem.RpcTransactionRequest];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_sendRawTransaction";
        Parameters: [signedTransaction: viem.Hex];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_sign";
        Parameters: [address: Address, data: viem.Hex];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_signTransaction";
        Parameters: [request: viem.RpcTransactionRequest];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_signTypedData_v4";
        Parameters: [address: Address, message: string];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_syncing";
        Parameters?: undefined;
        ReturnType: viem.NetworkSync | false;
    }, {
        Method: "personal_sign";
        Parameters: [data: viem.Hex, address: Address];
        ReturnType: viem.Hex;
    }, {
        Method: "wallet_addEthereumChain";
        Parameters: [chain: viem.AddEthereumChainParameter];
        ReturnType: null;
    }, {
        Method: "wallet_getCallsStatus";
        Parameters?: [string];
        ReturnType: viem.WalletGetCallsStatusReturnType;
    }, {
        Method: "wallet_getCapabilities";
        Parameters?: [Address];
        ReturnType: Prettify<viem.WalletCapabilitiesRecord>;
    }, {
        Method: "wallet_getPermissions";
        Parameters?: undefined;
        ReturnType: viem.WalletPermission[];
    }, {
        Method: "wallet_grantPermissions";
        Parameters?: [viem.WalletGrantPermissionsParameters];
        ReturnType: Prettify<viem.WalletGrantPermissionsReturnType>;
    }, {
        Method: "wallet_requestPermissions";
        Parameters: [permissions: {
            eth_accounts: Record<string, any>;
        }];
        ReturnType: viem.WalletPermission[];
    }, {
        Method: "wallet_revokePermissions";
        Parameters: [permissions: {
            eth_accounts: Record<string, any>;
        }];
        ReturnType: null;
    }, {
        Method: "wallet_sendCalls";
        Parameters?: viem.WalletSendCallsParameters;
        ReturnType: string;
    }, {
        Method: "wallet_showCallsStatus";
        Parameters?: [string];
        ReturnType: void;
    }, {
        Method: "wallet_switchEthereumChain";
        Parameters: [chain: {
            chainId: string;
        }];
        ReturnType: null;
    }, {
        Method: "wallet_watchAsset";
        Parameters: viem.WatchAssetParams;
        ReturnType: boolean;
    }, {
        Method: "eth_chainId";
        Parameters?: undefined;
        ReturnType: viem.Hex;
    }, {
        Method: "eth_estimateUserOperationGas";
        Parameters: [userOperation: viem.RpcUserOperation, entrypoint: Address] | [userOperation: viem.RpcUserOperation, entrypoint: Address, stateOverrideSet: viem.RpcStateOverride];
        ReturnType: viem.RpcEstimateUserOperationGasReturnType;
    }, {
        Method: "eth_getUserOperationByHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcGetUserOperationByHashReturnType | null;
    }, {
        Method: "eth_getUserOperationReceipt";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcUserOperationReceipt | null;
    }, {
        Method: "eth_sendUserOperation";
        Parameters: [userOperation: viem.RpcUserOperation, entrypoint: Address];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_supportedEntryPoints";
        Parameters?: undefined;
        ReturnType: readonly Address[];
    }, {
        Method: "pm_getPaymasterStubData";
        Parameters?: [userOperation: viem.OneOf<viem.PartialBy<Pick<viem.RpcUserOperation<"0.6">, "callData" | "callGasLimit" | "initCode" | "maxFeePerGas" | "maxPriorityFeePerGas" | "nonce" | "sender" | "preVerificationGas" | "verificationGasLimit">, "callGasLimit" | "initCode" | "maxFeePerGas" | "maxPriorityFeePerGas" | "preVerificationGas" | "verificationGasLimit"> | viem.PartialBy<Pick<viem.RpcUserOperation<"0.7">, "callData" | "callGasLimit" | "factory" | "factoryData" | "maxFeePerGas" | "maxPriorityFeePerGas" | "nonce" | "sender" | "preVerificationGas" | "verificationGasLimit">, "callGasLimit" | "factory" | "factoryData" | "maxFeePerGas" | "maxPriorityFeePerGas" | "preVerificationGas" | "verificationGasLimit">>, entrypoint: Address, chainId: viem.Hex, context: unknown];
        ReturnType: viem.OneOf<{
            paymasterAndData: viem.Hex;
        } | {
            paymaster: Address;
            paymasterData: viem.Hex;
            paymasterVerificationGasLimit: viem.Hex;
            paymasterPostOpGasLimit: viem.Hex;
        }> & {
            sponsor?: {
                name: string;
                icon?: string | undefined;
            } | undefined;
            isFinal?: boolean | undefined;
        };
    }, {
        Method: "pm_getPaymasterData";
        Parameters?: [userOperation: Pick<viem.RpcUserOperation<"0.6">, "callData" | "callGasLimit" | "initCode" | "maxFeePerGas" | "maxPriorityFeePerGas" | "nonce" | "sender" | "preVerificationGas" | "verificationGasLimit"> | Pick<viem.RpcUserOperation<"0.7">, "callData" | "callGasLimit" | "factory" | "factoryData" | "maxFeePerGas" | "maxPriorityFeePerGas" | "nonce" | "sender" | "preVerificationGas" | "verificationGasLimit">, entrypoint: Address, chainId: viem.Hex, context: unknown];
        ReturnType: viem.OneOf<{
            paymasterAndData: viem.Hex;
        } | {
            paymaster: Address;
            paymasterData: viem.Hex;
            paymasterVerificationGasLimit: viem.Hex;
            paymasterPostOpGasLimit: viem.Hex;
        }>;
    }] : T : never : never>;
    transport: viem.TransportConfig<"http", viem.EIP1193RequestFn> & {
        fetchOptions?: HttpTransportConfig["fetchOptions"] | undefined;
        url?: string | undefined;
    };
    type: string;
    uid: string;
    call: (parameters: viem.CallParameters<TChain>) => Promise<viem.CallReturnType>;
    createBlockFilter: () => Promise<viem.CreateBlockFilterReturnType>;
    createContractEventFilter: <const abi extends abitype.Abi | readonly unknown[], eventName extends viem.ContractEventName<abi> | undefined, args extends viem.MaybeExtractEventArgsFromAbi<abi, eventName> | undefined, strict extends boolean | undefined = undefined, fromBlock extends viem.BlockNumber | viem.BlockTag | undefined = undefined, toBlock extends viem.BlockNumber | viem.BlockTag | undefined = undefined>(args: viem.CreateContractEventFilterParameters<abi, eventName, args, strict, fromBlock, toBlock>) => Promise<viem.CreateContractEventFilterReturnType<abi, eventName, args, strict, fromBlock, toBlock>>;
    createEventFilter: <const abiEvent extends abitype.AbiEvent | undefined = undefined, const abiEvents extends readonly abitype.AbiEvent[] | readonly unknown[] | undefined = abiEvent extends abitype.AbiEvent ? [abiEvent] : undefined, strict extends boolean | undefined = undefined, fromBlock extends viem.BlockNumber | viem.BlockTag | undefined = undefined, toBlock extends viem.BlockNumber | viem.BlockTag | undefined = undefined, _EventName extends string | undefined = viem.MaybeAbiEventName<abiEvent>, _Args extends viem.MaybeExtractEventArgsFromAbi<abiEvents, _EventName> | undefined = undefined>(args?: viem.CreateEventFilterParameters<abiEvent, abiEvents, strict, fromBlock, toBlock, _EventName, _Args> | undefined) => Promise<viem.CreateEventFilterReturnType<abiEvent, abiEvents, strict, fromBlock, toBlock, _EventName, _Args>>;
    createPendingTransactionFilter: () => Promise<viem.CreatePendingTransactionFilterReturnType>;
    estimateContractGas: <chain extends Chain | undefined, const abi extends abitype.Abi | readonly unknown[], functionName extends viem.ContractFunctionName<abi, "nonpayable" | "payable">, args extends viem.ContractFunctionArgs<abi, "nonpayable" | "payable", functionName>>(args: viem.EstimateContractGasParameters<abi, functionName, args, chain>) => Promise<viem.EstimateContractGasReturnType>;
    estimateGas: (args: viem.EstimateGasParameters<TChain>) => Promise<viem.EstimateGasReturnType>;
    getBalance: (args: viem.GetBalanceParameters) => Promise<viem.GetBalanceReturnType>;
    getBlobBaseFee: () => Promise<viem.GetBlobBaseFeeReturnType>;
    getBlock: <includeTransactions extends boolean = false, blockTag extends viem.BlockTag = "latest">(args?: viem.GetBlockParameters<includeTransactions, blockTag> | undefined) => Promise<viem.FormattedBlock<TChain, includeTransactions, blockTag> extends infer T_1 ? { [K in keyof T_1]: viem.FormattedBlock<TChain, includeTransactions, blockTag>[K]; } : never>;
    getBlockNumber: (args?: viem.GetBlockNumberParameters | undefined) => Promise<viem.GetBlockNumberReturnType>;
    getBlockTransactionCount: (args?: viem.GetBlockTransactionCountParameters | undefined) => Promise<viem.GetBlockTransactionCountReturnType>;
    getBytecode: (args: viem.GetBytecodeParameters) => Promise<viem.GetBytecodeReturnType>;
    getChainId: () => Promise<viem.GetChainIdReturnType>;
    getCode: (args: viem.GetBytecodeParameters) => Promise<viem.GetBytecodeReturnType>;
    getContractEvents: <const abi extends abitype.Abi | readonly unknown[], eventName extends viem.ContractEventName<abi> | undefined = undefined, strict extends boolean | undefined = undefined, fromBlock extends viem.BlockNumber | viem.BlockTag | undefined = undefined, toBlock extends viem.BlockNumber | viem.BlockTag | undefined = undefined>(args: viem.GetContractEventsParameters<abi, eventName, strict, fromBlock, toBlock>) => Promise<viem.GetContractEventsReturnType<abi, eventName, strict, fromBlock, toBlock>>;
    getEip712Domain: (args: viem.GetEip712DomainParameters) => Promise<viem.GetEip712DomainReturnType>;
    getEnsAddress: (args: viem.GetEnsAddressParameters) => Promise<viem.GetEnsAddressReturnType>;
    getEnsAvatar: (args: viem.GetEnsAvatarParameters) => Promise<viem.GetEnsAvatarReturnType>;
    getEnsName: (args: viem.GetEnsNameParameters) => Promise<viem.GetEnsNameReturnType>;
    getEnsResolver: (args: viem.GetEnsResolverParameters) => Promise<viem.GetEnsResolverReturnType>;
    getEnsText: (args: viem.GetEnsTextParameters) => Promise<viem.GetEnsTextReturnType>;
    getFeeHistory: (args: viem.GetFeeHistoryParameters) => Promise<viem.GetFeeHistoryReturnType>;
    estimateFeesPerGas: <chainOverride extends Chain | undefined = undefined, type extends viem.FeeValuesType = "eip1559">(args?: viem.EstimateFeesPerGasParameters<TChain, chainOverride, type> | undefined) => Promise<viem.EstimateFeesPerGasReturnType<type>>;
    getFilterChanges: <filterType extends viem.FilterType, const abi extends abitype.Abi | readonly unknown[] | undefined, eventName extends string | undefined, strict extends boolean | undefined = undefined, fromBlock extends viem.BlockNumber | viem.BlockTag | undefined = undefined, toBlock extends viem.BlockNumber | viem.BlockTag | undefined = undefined>(args: viem.GetFilterChangesParameters<filterType, abi, eventName, strict, fromBlock, toBlock>) => Promise<viem.GetFilterChangesReturnType<filterType, abi, eventName, strict, fromBlock, toBlock>>;
    getFilterLogs: <const abi extends abitype.Abi | readonly unknown[] | undefined, eventName extends string | undefined, strict extends boolean | undefined = undefined, fromBlock extends viem.BlockNumber | viem.BlockTag | undefined = undefined, toBlock extends viem.BlockNumber | viem.BlockTag | undefined = undefined>(args: viem.GetFilterLogsParameters<abi, eventName, strict, fromBlock, toBlock>) => Promise<viem.GetFilterLogsReturnType<abi, eventName, strict, fromBlock, toBlock>>;
    getGasPrice: () => Promise<viem.GetGasPriceReturnType>;
    getLogs: <const abiEvent extends abitype.AbiEvent | undefined = undefined, const abiEvents extends readonly abitype.AbiEvent[] | readonly unknown[] | undefined = abiEvent extends abitype.AbiEvent ? [abiEvent] : undefined, strict extends boolean | undefined = undefined, fromBlock extends viem.BlockNumber | viem.BlockTag | undefined = undefined, toBlock extends viem.BlockNumber | viem.BlockTag | undefined = undefined>(args?: viem.GetLogsParameters<abiEvent, abiEvents, strict, fromBlock, toBlock> | undefined) => Promise<viem.GetLogsReturnType<abiEvent, abiEvents, strict, fromBlock, toBlock>>;
    getProof: (args: viem.GetProofParameters) => Promise<viem.GetProofReturnType>;
    estimateMaxPriorityFeePerGas: <chainOverride extends Chain | undefined = undefined>(args?: viem.GetChainParameter<TChain, chainOverride> | undefined) => Promise<viem.EstimateMaxPriorityFeePerGasReturnType>;
    getStorageAt: (args: viem.GetStorageAtParameters) => Promise<viem.GetStorageAtReturnType>;
    getTransaction: <blockTag extends viem.BlockTag = "latest">(args: viem.GetTransactionParameters<blockTag>) => Promise<viem.FormattedTransaction<TChain, blockTag> extends infer T_1 ? { [K in keyof T_1]: viem.FormattedTransaction<TChain, blockTag>[K]; } : never>;
    getTransactionConfirmations: (args: viem.GetTransactionConfirmationsParameters<TChain>) => Promise<viem.GetTransactionConfirmationsReturnType>;
    getTransactionCount: (args: viem.GetTransactionCountParameters) => Promise<viem.GetTransactionCountReturnType>;
    getTransactionReceipt: (args: viem.GetTransactionReceiptParameters) => Promise<viem.ExtractChainFormatterReturnType<TChain, "transactionReceipt", viem.TransactionReceipt>>;
    multicall: <const contracts extends readonly unknown[], allowFailure extends boolean = true>(args: viem.MulticallParameters<contracts, allowFailure>) => Promise<viem.MulticallReturnType<contracts, allowFailure>>;
    prepareTransactionRequest: <const request extends viem.PrepareTransactionRequestRequest<TChain, chainOverride>, chainOverride extends Chain | undefined = undefined, accountOverride extends Account | Address | undefined = undefined>(args: viem.PrepareTransactionRequestParameters<TChain, Account | undefined, chainOverride, accountOverride, request>) => Promise<viem.UnionRequiredBy<Extract<viem.UnionOmit<viem.ExtractChainFormatterParameters<viem.DeriveChain<TChain, chainOverride>, "transactionRequest", viem.TransactionRequest>, "from"> & (viem.DeriveChain<TChain, chainOverride> extends infer T_2 ? T_2 extends viem.DeriveChain<TChain, chainOverride> ? T_2 extends Chain ? {
        chain: T_2;
    } : {
        chain?: undefined;
    } : never : never) & (viem.DeriveAccount<Account | undefined, accountOverride> extends infer T_3 ? T_3 extends viem.DeriveAccount<Account | undefined, accountOverride> ? T_3 extends Account ? {
        account: T_3;
        from: Address;
    } : {
        account?: undefined;
        from?: undefined;
    } : never : never), viem.IsNever<((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_4 ? T_4 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_4 extends "legacy" ? viem.TransactionRequestLegacy : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_5 ? T_5 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_5 extends "eip1559" ? viem.TransactionRequestEIP1559 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_6 ? T_6 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_6 extends "eip2930" ? viem.TransactionRequestEIP2930 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_7 ? T_7 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_7 extends "eip4844" ? viem.TransactionRequestEIP4844 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_8 ? T_8 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_8 extends "eip7702" ? viem.TransactionRequestEIP7702 : never : never : never)> extends true ? unknown : viem.ExactPartial<((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_4 ? T_4 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_4 extends "legacy" ? viem.TransactionRequestLegacy : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_5 ? T_5 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_5 extends "eip1559" ? viem.TransactionRequestEIP1559 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_6 ? T_6 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_6 extends "eip2930" ? viem.TransactionRequestEIP2930 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_7 ? T_7 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_7 extends "eip4844" ? viem.TransactionRequestEIP4844 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_8 ? T_8 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_8 extends "eip7702" ? viem.TransactionRequestEIP7702 : never : never : never)>> & {
        chainId?: number | undefined;
    }, (request["parameters"] extends readonly viem.PrepareTransactionRequestParameterType[] ? request["parameters"][number] : "nonce" | "type" | "gas" | "blobVersionedHashes" | "fees" | "chainId") extends infer T_9 ? T_9 extends (request["parameters"] extends readonly viem.PrepareTransactionRequestParameterType[] ? request["parameters"][number] : "nonce" | "type" | "gas" | "blobVersionedHashes" | "fees" | "chainId") ? T_9 extends "fees" ? "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" : T_9 : never : never> & (unknown extends request["kzg"] ? {} : Pick<request, "kzg">) extends infer T_1 ? { [K in keyof T_1]: (viem.UnionRequiredBy<Extract<viem.UnionOmit<viem.ExtractChainFormatterParameters<viem.DeriveChain<TChain, chainOverride>, "transactionRequest", viem.TransactionRequest>, "from"> & (viem.DeriveChain<TChain, chainOverride> extends infer T_2 ? T_2 extends viem.DeriveChain<TChain, chainOverride> ? T_2 extends Chain ? {
        chain: T_2;
    } : {
        chain?: undefined;
    } : never : never) & (viem.DeriveAccount<Account | undefined, accountOverride> extends infer T_3 ? T_3 extends viem.DeriveAccount<Account | undefined, accountOverride> ? T_3 extends Account ? {
        account: T_3;
        from: Address;
    } : {
        account?: undefined;
        from?: undefined;
    } : never : never), viem.IsNever<((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_4 ? T_4 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_4 extends "legacy" ? viem.TransactionRequestLegacy : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_5 ? T_5 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_5 extends "eip1559" ? viem.TransactionRequestEIP1559 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_6 ? T_6 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_6 extends "eip2930" ? viem.TransactionRequestEIP2930 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_7 ? T_7 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_7 extends "eip4844" ? viem.TransactionRequestEIP4844 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_8 ? T_8 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_8 extends "eip7702" ? viem.TransactionRequestEIP7702 : never : never : never)> extends true ? unknown : viem.ExactPartial<((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_4 ? T_4 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_4 extends "legacy" ? viem.TransactionRequestLegacy : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_5 ? T_5 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_5 extends "eip1559" ? viem.TransactionRequestEIP1559 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_6 ? T_6 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_6 extends "eip2930" ? viem.TransactionRequestEIP2930 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_7 ? T_7 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_7 extends "eip4844" ? viem.TransactionRequestEIP4844 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_8 ? T_8 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_8 extends "eip7702" ? viem.TransactionRequestEIP7702 : never : never : never)>> & {
        chainId?: number | undefined;
    }, (request["parameters"] extends readonly viem.PrepareTransactionRequestParameterType[] ? request["parameters"][number] : "nonce" | "type" | "gas" | "blobVersionedHashes" | "fees" | "chainId") extends infer T_9 ? T_9 extends (request["parameters"] extends readonly viem.PrepareTransactionRequestParameterType[] ? request["parameters"][number] : "nonce" | "type" | "gas" | "blobVersionedHashes" | "fees" | "chainId") ? T_9 extends "fees" ? "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" : T_9 : never : never> & (unknown extends request["kzg"] ? {} : Pick<request, "kzg">))[K]; } : never>;
    readContract: <const abi extends abitype.Abi | readonly unknown[], functionName extends viem.ContractFunctionName<abi, "pure" | "view">, args extends viem.ContractFunctionArgs<abi, "pure" | "view", functionName>>(args: viem.ReadContractParameters<abi, functionName, args>) => Promise<viem.ReadContractReturnType<abi, functionName, args>>;
    sendRawTransaction: (args: viem.SendRawTransactionParameters) => Promise<viem.SendRawTransactionReturnType>;
    simulateContract: <const abi extends abitype.Abi | readonly unknown[], functionName extends viem.ContractFunctionName<abi, "nonpayable" | "payable">, args_1 extends viem.ContractFunctionArgs<abi, "nonpayable" | "payable", functionName>, chainOverride extends Chain | undefined, accountOverride extends Account | Address | undefined = undefined>(args: viem.SimulateContractParameters<abi, functionName, args_1, TChain, chainOverride, accountOverride>) => Promise<viem.SimulateContractReturnType<abi, functionName, args_1, TChain, Account | undefined, chainOverride, accountOverride>>;
    verifyMessage: (args: viem.VerifyMessageActionParameters) => Promise<viem.VerifyMessageActionReturnType>;
    verifySiweMessage: (args: {
        blockNumber?: bigint | undefined;
        blockTag?: viem.BlockTag | undefined;
        nonce?: string | undefined;
        address?: Address | undefined;
        domain?: string | undefined;
        scheme?: string | undefined;
        time?: Date | undefined;
        message: string;
        signature: viem.Hex;
    }) => Promise<boolean>;
    verifyTypedData: (args: viem.VerifyTypedDataActionParameters) => Promise<viem.VerifyTypedDataActionReturnType>;
    uninstallFilter: (args: viem.UninstallFilterParameters) => Promise<viem.UninstallFilterReturnType>;
    waitForTransactionReceipt: (args: viem.WaitForTransactionReceiptParameters<TChain>) => Promise<viem.ExtractChainFormatterReturnType<TChain, "transactionReceipt", viem.TransactionReceipt>>;
    watchBlockNumber: (args: viem.WatchBlockNumberParameters) => viem.WatchBlockNumberReturnType;
    watchBlocks: <includeTransactions extends boolean = false, blockTag extends viem.BlockTag = "latest">(args: viem.WatchBlocksParameters<HttpTransport, TChain, includeTransactions, blockTag>) => viem.WatchBlocksReturnType;
    watchContractEvent: <const abi extends abitype.Abi | readonly unknown[], eventName extends viem.ContractEventName<abi>, strict extends boolean | undefined = undefined>(args: viem.WatchContractEventParameters<abi, eventName, strict, HttpTransport>) => viem.WatchContractEventReturnType;
    watchEvent: <const abiEvent extends abitype.AbiEvent | undefined = undefined, const abiEvents extends readonly abitype.AbiEvent[] | readonly unknown[] | undefined = abiEvent extends abitype.AbiEvent ? [abiEvent] : undefined, strict extends boolean | undefined = undefined>(args: viem.WatchEventParameters<abiEvent, abiEvents, strict, HttpTransport>) => viem.WatchEventReturnType;
    watchPendingTransactions: (args: viem.WatchPendingTransactionsParameters<HttpTransport>) => viem.WatchPendingTransactionsReturnType;
    extend: <const client extends {
        [x: string]: unknown;
        account?: undefined;
        batch?: undefined;
        cacheTime?: undefined;
        ccipRead?: undefined;
        chain?: undefined;
        key?: undefined;
        name?: undefined;
        pollingInterval?: undefined;
        request?: undefined;
        transport?: undefined;
        type?: undefined;
        uid?: undefined;
    } & viem.ExactPartial<Pick<viem.PublicActions<HttpTransport, TChain, undefined>, "call" | "createContractEventFilter" | "createEventFilter" | "estimateContractGas" | "estimateGas" | "getBlock" | "getBlockNumber" | "getChainId" | "getContractEvents" | "getEnsText" | "getFilterChanges" | "getGasPrice" | "getLogs" | "getTransaction" | "getTransactionCount" | "getTransactionReceipt" | "prepareTransactionRequest" | "readContract" | "sendRawTransaction" | "simulateContract" | "uninstallFilter" | "watchBlockNumber" | "watchContractEvent"> & Pick<viem.WalletActions<TChain, undefined>, "sendTransaction" | "writeContract">>>(fn: (client: viem.Client<HttpTransport, TChain, undefined, TRpcSchema extends RpcSchema ? [{
        Method: "web3_clientVersion";
        Parameters?: undefined;
        ReturnType: string;
    }, {
        Method: "web3_sha3";
        Parameters: [data: viem.Hash];
        ReturnType: string;
    }, {
        Method: "net_listening";
        Parameters?: undefined;
        ReturnType: boolean;
    }, {
        Method: "net_peerCount";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "net_version";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_blobBaseFee";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_blockNumber";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_call";
        Parameters: [transaction: viem.ExactPartial<viem.RpcTransactionRequest>] | [transaction: viem.ExactPartial<viem.RpcTransactionRequest>, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier] | [transaction: viem.ExactPartial<viem.RpcTransactionRequest>, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier, stateOverrideSet: viem.RpcStateOverride];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_chainId";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_coinbase";
        Parameters?: undefined;
        ReturnType: Address;
    }, {
        Method: "eth_estimateGas";
        Parameters: [transaction: viem.RpcTransactionRequest] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag, stateOverride: viem.RpcStateOverride];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_feeHistory";
        Parameters: [blockCount: viem.Quantity, newestBlock: viem.RpcBlockNumber | viem.BlockTag, rewardPercentiles: number[] | undefined];
        ReturnType: viem.RpcFeeHistory;
    }, {
        Method: "eth_gasPrice";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBalance";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBlockByHash";
        Parameters: [hash: viem.Hash, includeTransactionObjects: boolean];
        ReturnType: viem.RpcBlock | null;
    }, {
        Method: "eth_getBlockByNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, includeTransactionObjects: boolean];
        ReturnType: viem.RpcBlock | null;
    }, {
        Method: "eth_getBlockTransactionCountByHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBlockTransactionCountByNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getCode";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_getFilterChanges";
        Parameters: [filterId: viem.Quantity];
        ReturnType: viem.RpcLog[] | viem.Hex[];
    }, {
        Method: "eth_getFilterLogs";
        Parameters: [filterId: viem.Quantity];
        ReturnType: viem.RpcLog[];
    }, {
        Method: "eth_getLogs";
        Parameters: [{
            address?: Address | Address[] | undefined;
            topics?: viem.LogTopic[] | undefined;
        } & ({
            fromBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            toBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            blockHash?: undefined;
        } | {
            fromBlock?: undefined;
            toBlock?: undefined;
            blockHash?: viem.Hash | undefined;
        })];
        ReturnType: viem.RpcLog[];
    }, {
        Method: "eth_getProof";
        Parameters: [address: Address, storageKeys: viem.Hash[], block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.RpcProof;
    }, {
        Method: "eth_getStorageAt";
        Parameters: [address: Address, index: viem.Quantity, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_getTransactionByBlockHashAndIndex";
        Parameters: [hash: viem.Hash, index: viem.Quantity];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionByBlockNumberAndIndex";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, index: viem.Quantity];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionByHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionCount";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getTransactionReceipt";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcTransactionReceipt | null;
    }, {
        Method: "eth_getUncleByBlockHashAndIndex";
        Parameters: [hash: viem.Hash, index: viem.Quantity];
        ReturnType: viem.RpcUncle | null;
    }, {
        Method: "eth_getUncleByBlockNumberAndIndex";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, index: viem.Quantity];
        ReturnType: viem.RpcUncle | null;
    }, {
        Method: "eth_getUncleCountByBlockHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getUncleCountByBlockNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_maxPriorityFeePerGas";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newBlockFilter";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newFilter";
        Parameters: [filter: {
            fromBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            toBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            address?: Address | Address[] | undefined;
            topics?: viem.LogTopic[] | undefined;
        }];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newPendingTransactionFilter";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_protocolVersion";
        Parameters?: undefined;
        ReturnType: string;
    }, {
        Method: "eth_sendRawTransaction";
        Parameters: [signedTransaction: viem.Hex];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_uninstallFilter";
        Parameters: [filterId: viem.Quantity];
        ReturnType: boolean;
    }, ...TRpcSchema] : viem.PublicRpcSchema, viem.PublicActions<HttpTransport, TChain>>) => client) => viem.Client<HttpTransport, TChain, undefined, TRpcSchema extends RpcSchema ? [{
        Method: "web3_clientVersion";
        Parameters?: undefined;
        ReturnType: string;
    }, {
        Method: "web3_sha3";
        Parameters: [data: viem.Hash];
        ReturnType: string;
    }, {
        Method: "net_listening";
        Parameters?: undefined;
        ReturnType: boolean;
    }, {
        Method: "net_peerCount";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "net_version";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_blobBaseFee";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_blockNumber";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_call";
        Parameters: [transaction: viem.ExactPartial<viem.RpcTransactionRequest>] | [transaction: viem.ExactPartial<viem.RpcTransactionRequest>, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier] | [transaction: viem.ExactPartial<viem.RpcTransactionRequest>, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier, stateOverrideSet: viem.RpcStateOverride];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_chainId";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_coinbase";
        Parameters?: undefined;
        ReturnType: Address;
    }, {
        Method: "eth_estimateGas";
        Parameters: [transaction: viem.RpcTransactionRequest] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag, stateOverride: viem.RpcStateOverride];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_feeHistory";
        Parameters: [blockCount: viem.Quantity, newestBlock: viem.RpcBlockNumber | viem.BlockTag, rewardPercentiles: number[] | undefined];
        ReturnType: viem.RpcFeeHistory;
    }, {
        Method: "eth_gasPrice";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBalance";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBlockByHash";
        Parameters: [hash: viem.Hash, includeTransactionObjects: boolean];
        ReturnType: viem.RpcBlock | null;
    }, {
        Method: "eth_getBlockByNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, includeTransactionObjects: boolean];
        ReturnType: viem.RpcBlock | null;
    }, {
        Method: "eth_getBlockTransactionCountByHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBlockTransactionCountByNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getCode";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_getFilterChanges";
        Parameters: [filterId: viem.Quantity];
        ReturnType: viem.RpcLog[] | viem.Hex[];
    }, {
        Method: "eth_getFilterLogs";
        Parameters: [filterId: viem.Quantity];
        ReturnType: viem.RpcLog[];
    }, {
        Method: "eth_getLogs";
        Parameters: [{
            address?: Address | Address[] | undefined;
            topics?: viem.LogTopic[] | undefined;
        } & ({
            fromBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            toBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            blockHash?: undefined;
        } | {
            fromBlock?: undefined;
            toBlock?: undefined;
            blockHash?: viem.Hash | undefined;
        })];
        ReturnType: viem.RpcLog[];
    }, {
        Method: "eth_getProof";
        Parameters: [address: Address, storageKeys: viem.Hash[], block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.RpcProof;
    }, {
        Method: "eth_getStorageAt";
        Parameters: [address: Address, index: viem.Quantity, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_getTransactionByBlockHashAndIndex";
        Parameters: [hash: viem.Hash, index: viem.Quantity];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionByBlockNumberAndIndex";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, index: viem.Quantity];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionByHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionCount";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getTransactionReceipt";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcTransactionReceipt | null;
    }, {
        Method: "eth_getUncleByBlockHashAndIndex";
        Parameters: [hash: viem.Hash, index: viem.Quantity];
        ReturnType: viem.RpcUncle | null;
    }, {
        Method: "eth_getUncleByBlockNumberAndIndex";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, index: viem.Quantity];
        ReturnType: viem.RpcUncle | null;
    }, {
        Method: "eth_getUncleCountByBlockHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getUncleCountByBlockNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_maxPriorityFeePerGas";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newBlockFilter";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newFilter";
        Parameters: [filter: {
            fromBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            toBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            address?: Address | Address[] | undefined;
            topics?: viem.LogTopic[] | undefined;
        }];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newPendingTransactionFilter";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_protocolVersion";
        Parameters?: undefined;
        ReturnType: string;
    }, {
        Method: "eth_sendRawTransaction";
        Parameters: [signedTransaction: viem.Hex];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_uninstallFilter";
        Parameters: [filterId: viem.Quantity];
        ReturnType: boolean;
    }, ...TRpcSchema] : viem.PublicRpcSchema, { [K in keyof client]: client[K]; } & viem.PublicActions<HttpTransport, TChain>>;
};
/**
 * Creates a Viem wallet client for interacting with the blockchain.
 *
 * @template TChain - The chain type
 * @template TAccount - The account type (optional)
 * @template TRpcSchema - The RPC schema type (optional)
 * @param parameters - Configuration parameters for the wallet client
 * @returns A wallet client instance for making blockchain transactions
 * @throws {Error} If NEXT_PUBLIC_SETTLEMINT_APP_URL is not defined in the environment
 *
 * @example
 * ```typescript
 * const walletClient = createViemWalletClient({
 *   chain: mainnet,
 *   transportConfig: { timeout: 30000 }
 * });
 * ```
 */
declare function createViemWalletClient<TChain extends Chain, TAccount extends Account | Address | undefined = undefined, TRpcSchema extends RpcSchema | undefined = undefined>(parameters: ViemConfig<TChain, TAccount, TRpcSchema>): {
    account: undefined;
    batch?: viem.ClientConfig["batch"] | undefined;
    cacheTime: number;
    ccipRead?: viem.ClientConfig["ccipRead"] | undefined;
    chain: TChain;
    key: string;
    name: string;
    pollingInterval: number;
    request: viem.EIP1193RequestFn<(TRpcSchema extends RpcSchema ? [{
        Method: "eth_accounts";
        Parameters?: undefined;
        ReturnType: Address[];
    }, {
        Method: "eth_chainId";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_estimateGas";
        Parameters: [transaction: viem.RpcTransactionRequest] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag, stateOverride: viem.RpcStateOverride];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_requestAccounts";
        Parameters?: undefined;
        ReturnType: Address[];
    }, {
        Method: "eth_sendTransaction";
        Parameters: [transaction: viem.RpcTransactionRequest];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_sendRawTransaction";
        Parameters: [signedTransaction: viem.Hex];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_sign";
        Parameters: [address: Address, data: viem.Hex];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_signTransaction";
        Parameters: [request: viem.RpcTransactionRequest];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_signTypedData_v4";
        Parameters: [address: Address, message: string];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_syncing";
        Parameters?: undefined;
        ReturnType: viem.NetworkSync | false;
    }, {
        Method: "personal_sign";
        Parameters: [data: viem.Hex, address: Address];
        ReturnType: viem.Hex;
    }, {
        Method: "wallet_addEthereumChain";
        Parameters: [chain: viem.AddEthereumChainParameter];
        ReturnType: null;
    }, {
        Method: "wallet_getCallsStatus";
        Parameters?: [string];
        ReturnType: viem.WalletGetCallsStatusReturnType;
    }, {
        Method: "wallet_getCapabilities";
        Parameters?: [Address];
        ReturnType: Prettify<viem.WalletCapabilitiesRecord>;
    }, {
        Method: "wallet_getPermissions";
        Parameters?: undefined;
        ReturnType: viem.WalletPermission[];
    }, {
        Method: "wallet_grantPermissions";
        Parameters?: [viem.WalletGrantPermissionsParameters];
        ReturnType: Prettify<viem.WalletGrantPermissionsReturnType>;
    }, {
        Method: "wallet_requestPermissions";
        Parameters: [permissions: {
            eth_accounts: Record<string, any>;
        }];
        ReturnType: viem.WalletPermission[];
    }, {
        Method: "wallet_revokePermissions";
        Parameters: [permissions: {
            eth_accounts: Record<string, any>;
        }];
        ReturnType: null;
    }, {
        Method: "wallet_sendCalls";
        Parameters?: viem.WalletSendCallsParameters;
        ReturnType: string;
    }, {
        Method: "wallet_showCallsStatus";
        Parameters?: [string];
        ReturnType: void;
    }, {
        Method: "wallet_switchEthereumChain";
        Parameters: [chain: {
            chainId: string;
        }];
        ReturnType: null;
    }, {
        Method: "wallet_watchAsset";
        Parameters: viem.WatchAssetParams;
        ReturnType: boolean;
    }, ...TRpcSchema] : viem.WalletRpcSchema) extends infer T ? T extends (TRpcSchema extends RpcSchema ? [{
        Method: "eth_accounts";
        Parameters?: undefined;
        ReturnType: Address[];
    }, {
        Method: "eth_chainId";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_estimateGas";
        Parameters: [transaction: viem.RpcTransactionRequest] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag, stateOverride: viem.RpcStateOverride];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_requestAccounts";
        Parameters?: undefined;
        ReturnType: Address[];
    }, {
        Method: "eth_sendTransaction";
        Parameters: [transaction: viem.RpcTransactionRequest];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_sendRawTransaction";
        Parameters: [signedTransaction: viem.Hex];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_sign";
        Parameters: [address: Address, data: viem.Hex];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_signTransaction";
        Parameters: [request: viem.RpcTransactionRequest];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_signTypedData_v4";
        Parameters: [address: Address, message: string];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_syncing";
        Parameters?: undefined;
        ReturnType: viem.NetworkSync | false;
    }, {
        Method: "personal_sign";
        Parameters: [data: viem.Hex, address: Address];
        ReturnType: viem.Hex;
    }, {
        Method: "wallet_addEthereumChain";
        Parameters: [chain: viem.AddEthereumChainParameter];
        ReturnType: null;
    }, {
        Method: "wallet_getCallsStatus";
        Parameters?: [string];
        ReturnType: viem.WalletGetCallsStatusReturnType;
    }, {
        Method: "wallet_getCapabilities";
        Parameters?: [Address];
        ReturnType: Prettify<viem.WalletCapabilitiesRecord>;
    }, {
        Method: "wallet_getPermissions";
        Parameters?: undefined;
        ReturnType: viem.WalletPermission[];
    }, {
        Method: "wallet_grantPermissions";
        Parameters?: [viem.WalletGrantPermissionsParameters];
        ReturnType: Prettify<viem.WalletGrantPermissionsReturnType>;
    }, {
        Method: "wallet_requestPermissions";
        Parameters: [permissions: {
            eth_accounts: Record<string, any>;
        }];
        ReturnType: viem.WalletPermission[];
    }, {
        Method: "wallet_revokePermissions";
        Parameters: [permissions: {
            eth_accounts: Record<string, any>;
        }];
        ReturnType: null;
    }, {
        Method: "wallet_sendCalls";
        Parameters?: viem.WalletSendCallsParameters;
        ReturnType: string;
    }, {
        Method: "wallet_showCallsStatus";
        Parameters?: [string];
        ReturnType: void;
    }, {
        Method: "wallet_switchEthereumChain";
        Parameters: [chain: {
            chainId: string;
        }];
        ReturnType: null;
    }, {
        Method: "wallet_watchAsset";
        Parameters: viem.WatchAssetParams;
        ReturnType: boolean;
    }, ...TRpcSchema] : viem.WalletRpcSchema) ? T extends undefined ? [{
        Method: "web3_clientVersion";
        Parameters?: undefined;
        ReturnType: string;
    }, {
        Method: "web3_sha3";
        Parameters: [data: viem.Hash];
        ReturnType: string;
    }, {
        Method: "net_listening";
        Parameters?: undefined;
        ReturnType: boolean;
    }, {
        Method: "net_peerCount";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "net_version";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_blobBaseFee";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_blockNumber";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_call";
        Parameters: [transaction: viem.ExactPartial<viem.RpcTransactionRequest>] | [transaction: viem.ExactPartial<viem.RpcTransactionRequest>, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier] | [transaction: viem.ExactPartial<viem.RpcTransactionRequest>, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier, stateOverrideSet: viem.RpcStateOverride];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_chainId";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_coinbase";
        Parameters?: undefined;
        ReturnType: Address;
    }, {
        Method: "eth_estimateGas";
        Parameters: [transaction: viem.RpcTransactionRequest] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag, stateOverride: viem.RpcStateOverride];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_feeHistory";
        Parameters: [blockCount: viem.Quantity, newestBlock: viem.RpcBlockNumber | viem.BlockTag, rewardPercentiles: number[] | undefined];
        ReturnType: viem.RpcFeeHistory;
    }, {
        Method: "eth_gasPrice";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBalance";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBlockByHash";
        Parameters: [hash: viem.Hash, includeTransactionObjects: boolean];
        ReturnType: viem.RpcBlock | null;
    }, {
        Method: "eth_getBlockByNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, includeTransactionObjects: boolean];
        ReturnType: viem.RpcBlock | null;
    }, {
        Method: "eth_getBlockTransactionCountByHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getBlockTransactionCountByNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getCode";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_getFilterChanges";
        Parameters: [filterId: viem.Quantity];
        ReturnType: viem.RpcLog[] | viem.Hex[];
    }, {
        Method: "eth_getFilterLogs";
        Parameters: [filterId: viem.Quantity];
        ReturnType: viem.RpcLog[];
    }, {
        Method: "eth_getLogs";
        Parameters: [{
            address?: Address | Address[] | undefined;
            topics?: viem.LogTopic[] | undefined;
        } & ({
            fromBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            toBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            blockHash?: undefined;
        } | {
            fromBlock?: undefined;
            toBlock?: undefined;
            blockHash?: viem.Hash | undefined;
        })];
        ReturnType: viem.RpcLog[];
    }, {
        Method: "eth_getProof";
        Parameters: [address: Address, storageKeys: viem.Hash[], block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.RpcProof;
    }, {
        Method: "eth_getStorageAt";
        Parameters: [address: Address, index: viem.Quantity, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_getTransactionByBlockHashAndIndex";
        Parameters: [hash: viem.Hash, index: viem.Quantity];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionByBlockNumberAndIndex";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, index: viem.Quantity];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionByHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcTransaction | null;
    }, {
        Method: "eth_getTransactionCount";
        Parameters: [address: Address, block: viem.RpcBlockNumber | viem.BlockTag | viem.RpcBlockIdentifier];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getTransactionReceipt";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcTransactionReceipt | null;
    }, {
        Method: "eth_getUncleByBlockHashAndIndex";
        Parameters: [hash: viem.Hash, index: viem.Quantity];
        ReturnType: viem.RpcUncle | null;
    }, {
        Method: "eth_getUncleByBlockNumberAndIndex";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag, index: viem.Quantity];
        ReturnType: viem.RpcUncle | null;
    }, {
        Method: "eth_getUncleCountByBlockHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_getUncleCountByBlockNumber";
        Parameters: [block: viem.RpcBlockNumber | viem.BlockTag];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_maxPriorityFeePerGas";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newBlockFilter";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newFilter";
        Parameters: [filter: {
            fromBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            toBlock?: viem.RpcBlockNumber | viem.BlockTag | undefined;
            address?: Address | Address[] | undefined;
            topics?: viem.LogTopic[] | undefined;
        }];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_newPendingTransactionFilter";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_protocolVersion";
        Parameters?: undefined;
        ReturnType: string;
    }, {
        Method: "eth_sendRawTransaction";
        Parameters: [signedTransaction: viem.Hex];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_uninstallFilter";
        Parameters: [filterId: viem.Quantity];
        ReturnType: boolean;
    }, {
        Method: "eth_accounts";
        Parameters?: undefined;
        ReturnType: Address[];
    }, {
        Method: "eth_chainId";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_estimateGas";
        Parameters: [transaction: viem.RpcTransactionRequest] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag, stateOverride: viem.RpcStateOverride];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_requestAccounts";
        Parameters?: undefined;
        ReturnType: Address[];
    }, {
        Method: "eth_sendTransaction";
        Parameters: [transaction: viem.RpcTransactionRequest];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_sendRawTransaction";
        Parameters: [signedTransaction: viem.Hex];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_sign";
        Parameters: [address: Address, data: viem.Hex];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_signTransaction";
        Parameters: [request: viem.RpcTransactionRequest];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_signTypedData_v4";
        Parameters: [address: Address, message: string];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_syncing";
        Parameters?: undefined;
        ReturnType: viem.NetworkSync | false;
    }, {
        Method: "personal_sign";
        Parameters: [data: viem.Hex, address: Address];
        ReturnType: viem.Hex;
    }, {
        Method: "wallet_addEthereumChain";
        Parameters: [chain: viem.AddEthereumChainParameter];
        ReturnType: null;
    }, {
        Method: "wallet_getCallsStatus";
        Parameters?: [string];
        ReturnType: viem.WalletGetCallsStatusReturnType;
    }, {
        Method: "wallet_getCapabilities";
        Parameters?: [Address];
        ReturnType: Prettify<viem.WalletCapabilitiesRecord>;
    }, {
        Method: "wallet_getPermissions";
        Parameters?: undefined;
        ReturnType: viem.WalletPermission[];
    }, {
        Method: "wallet_grantPermissions";
        Parameters?: [viem.WalletGrantPermissionsParameters];
        ReturnType: Prettify<viem.WalletGrantPermissionsReturnType>;
    }, {
        Method: "wallet_requestPermissions";
        Parameters: [permissions: {
            eth_accounts: Record<string, any>;
        }];
        ReturnType: viem.WalletPermission[];
    }, {
        Method: "wallet_revokePermissions";
        Parameters: [permissions: {
            eth_accounts: Record<string, any>;
        }];
        ReturnType: null;
    }, {
        Method: "wallet_sendCalls";
        Parameters?: viem.WalletSendCallsParameters;
        ReturnType: string;
    }, {
        Method: "wallet_showCallsStatus";
        Parameters?: [string];
        ReturnType: void;
    }, {
        Method: "wallet_switchEthereumChain";
        Parameters: [chain: {
            chainId: string;
        }];
        ReturnType: null;
    }, {
        Method: "wallet_watchAsset";
        Parameters: viem.WatchAssetParams;
        ReturnType: boolean;
    }, {
        Method: "eth_chainId";
        Parameters?: undefined;
        ReturnType: viem.Hex;
    }, {
        Method: "eth_estimateUserOperationGas";
        Parameters: [userOperation: viem.RpcUserOperation, entrypoint: Address] | [userOperation: viem.RpcUserOperation, entrypoint: Address, stateOverrideSet: viem.RpcStateOverride];
        ReturnType: viem.RpcEstimateUserOperationGasReturnType;
    }, {
        Method: "eth_getUserOperationByHash";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcGetUserOperationByHashReturnType | null;
    }, {
        Method: "eth_getUserOperationReceipt";
        Parameters: [hash: viem.Hash];
        ReturnType: viem.RpcUserOperationReceipt | null;
    }, {
        Method: "eth_sendUserOperation";
        Parameters: [userOperation: viem.RpcUserOperation, entrypoint: Address];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_supportedEntryPoints";
        Parameters?: undefined;
        ReturnType: readonly Address[];
    }, {
        Method: "pm_getPaymasterStubData";
        Parameters?: [userOperation: viem.OneOf<viem.PartialBy<Pick<viem.RpcUserOperation<"0.6">, "callData" | "callGasLimit" | "initCode" | "maxFeePerGas" | "maxPriorityFeePerGas" | "nonce" | "sender" | "preVerificationGas" | "verificationGasLimit">, "callGasLimit" | "initCode" | "maxFeePerGas" | "maxPriorityFeePerGas" | "preVerificationGas" | "verificationGasLimit"> | viem.PartialBy<Pick<viem.RpcUserOperation<"0.7">, "callData" | "callGasLimit" | "factory" | "factoryData" | "maxFeePerGas" | "maxPriorityFeePerGas" | "nonce" | "sender" | "preVerificationGas" | "verificationGasLimit">, "callGasLimit" | "factory" | "factoryData" | "maxFeePerGas" | "maxPriorityFeePerGas" | "preVerificationGas" | "verificationGasLimit">>, entrypoint: Address, chainId: viem.Hex, context: unknown];
        ReturnType: viem.OneOf<{
            paymasterAndData: viem.Hex;
        } | {
            paymaster: Address;
            paymasterData: viem.Hex;
            paymasterVerificationGasLimit: viem.Hex;
            paymasterPostOpGasLimit: viem.Hex;
        }> & {
            sponsor?: {
                name: string;
                icon?: string | undefined;
            } | undefined;
            isFinal?: boolean | undefined;
        };
    }, {
        Method: "pm_getPaymasterData";
        Parameters?: [userOperation: Pick<viem.RpcUserOperation<"0.6">, "callData" | "callGasLimit" | "initCode" | "maxFeePerGas" | "maxPriorityFeePerGas" | "nonce" | "sender" | "preVerificationGas" | "verificationGasLimit"> | Pick<viem.RpcUserOperation<"0.7">, "callData" | "callGasLimit" | "factory" | "factoryData" | "maxFeePerGas" | "maxPriorityFeePerGas" | "nonce" | "sender" | "preVerificationGas" | "verificationGasLimit">, entrypoint: Address, chainId: viem.Hex, context: unknown];
        ReturnType: viem.OneOf<{
            paymasterAndData: viem.Hex;
        } | {
            paymaster: Address;
            paymasterData: viem.Hex;
            paymasterVerificationGasLimit: viem.Hex;
            paymasterPostOpGasLimit: viem.Hex;
        }>;
    }] : T : never : never>;
    transport: viem.TransportConfig<"http", viem.EIP1193RequestFn> & {
        fetchOptions?: HttpTransportConfig["fetchOptions"] | undefined;
        url?: string | undefined;
    };
    type: string;
    uid: string;
    addChain: (args: viem.AddChainParameters) => Promise<void>;
    deployContract: <const abi extends abitype.Abi | readonly unknown[], chainOverride extends Chain | undefined>(args: viem.DeployContractParameters<abi, TChain, undefined, chainOverride>) => Promise<viem.DeployContractReturnType>;
    getAddresses: () => Promise<viem.GetAddressesReturnType>;
    getChainId: () => Promise<viem.GetChainIdReturnType>;
    getPermissions: () => Promise<viem.GetPermissionsReturnType>;
    prepareTransactionRequest: <const request extends viem.PrepareTransactionRequestRequest<TChain, chainOverride>, chainOverride extends Chain | undefined = undefined, accountOverride extends Account | Address | undefined = undefined>(args: viem.PrepareTransactionRequestParameters<TChain, undefined, chainOverride, accountOverride, request>) => Promise<viem.UnionRequiredBy<Extract<viem.UnionOmit<viem.ExtractChainFormatterParameters<viem.DeriveChain<TChain, chainOverride>, "transactionRequest", viem.TransactionRequest>, "from"> & (viem.DeriveChain<TChain, chainOverride> extends infer T_2 ? T_2 extends viem.DeriveChain<TChain, chainOverride> ? T_2 extends Chain ? {
        chain: T_2;
    } : {
        chain?: undefined;
    } : never : never) & (viem.DeriveAccount<undefined, accountOverride> extends infer T_3 ? T_3 extends viem.DeriveAccount<undefined, accountOverride> ? T_3 extends Account ? {
        account: T_3;
        from: Address;
    } : {
        account?: undefined;
        from?: undefined;
    } : never : never), viem.IsNever<((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_4 ? T_4 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_4 extends "legacy" ? viem.TransactionRequestLegacy : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_5 ? T_5 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_5 extends "eip1559" ? viem.TransactionRequestEIP1559 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_6 ? T_6 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_6 extends "eip2930" ? viem.TransactionRequestEIP2930 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_7 ? T_7 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_7 extends "eip4844" ? viem.TransactionRequestEIP4844 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_8 ? T_8 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_8 extends "eip7702" ? viem.TransactionRequestEIP7702 : never : never : never)> extends true ? unknown : viem.ExactPartial<((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_4 ? T_4 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_4 extends "legacy" ? viem.TransactionRequestLegacy : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_5 ? T_5 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_5 extends "eip1559" ? viem.TransactionRequestEIP1559 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_6 ? T_6 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_6 extends "eip2930" ? viem.TransactionRequestEIP2930 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_7 ? T_7 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_7 extends "eip4844" ? viem.TransactionRequestEIP4844 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_8 ? T_8 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_8 extends "eip7702" ? viem.TransactionRequestEIP7702 : never : never : never)>> & {
        chainId?: number | undefined;
    }, (request["parameters"] extends readonly viem.PrepareTransactionRequestParameterType[] ? request["parameters"][number] : "nonce" | "type" | "gas" | "blobVersionedHashes" | "fees" | "chainId") extends infer T_9 ? T_9 extends (request["parameters"] extends readonly viem.PrepareTransactionRequestParameterType[] ? request["parameters"][number] : "nonce" | "type" | "gas" | "blobVersionedHashes" | "fees" | "chainId") ? T_9 extends "fees" ? "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" : T_9 : never : never> & (unknown extends request["kzg"] ? {} : Pick<request, "kzg">) extends infer T_1 ? { [K in keyof T_1]: (viem.UnionRequiredBy<Extract<viem.UnionOmit<viem.ExtractChainFormatterParameters<viem.DeriveChain<TChain, chainOverride>, "transactionRequest", viem.TransactionRequest>, "from"> & (viem.DeriveChain<TChain, chainOverride> extends infer T_2 ? T_2 extends viem.DeriveChain<TChain, chainOverride> ? T_2 extends Chain ? {
        chain: T_2;
    } : {
        chain?: undefined;
    } : never : never) & (viem.DeriveAccount<undefined, accountOverride> extends infer T_3 ? T_3 extends viem.DeriveAccount<undefined, accountOverride> ? T_3 extends Account ? {
        account: T_3;
        from: Address;
    } : {
        account?: undefined;
        from?: undefined;
    } : never : never), viem.IsNever<((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_4 ? T_4 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_4 extends "legacy" ? viem.TransactionRequestLegacy : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_5 ? T_5 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_5 extends "eip1559" ? viem.TransactionRequestEIP1559 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_6 ? T_6 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_6 extends "eip2930" ? viem.TransactionRequestEIP2930 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_7 ? T_7 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_7 extends "eip4844" ? viem.TransactionRequestEIP4844 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_8 ? T_8 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_8 extends "eip7702" ? viem.TransactionRequestEIP7702 : never : never : never)> extends true ? unknown : viem.ExactPartial<((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_4 ? T_4 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_4 extends "legacy" ? viem.TransactionRequestLegacy : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_5 ? T_5 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_5 extends "eip1559" ? viem.TransactionRequestEIP1559 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_6 ? T_6 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_6 extends "eip2930" ? viem.TransactionRequestEIP2930 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_7 ? T_7 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_7 extends "eip4844" ? viem.TransactionRequestEIP4844 : never : never : never) | ((request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) extends infer T_8 ? T_8 extends (request["type"] extends string | undefined ? request["type"] : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)> extends "legacy" ? unknown : viem.GetTransactionType<request, (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.FeeValuesLegacy) | (viem.ValueOf<Required<{ [K_1 in keyof request]: K_1 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "r" | "s" | "v" | "yParity" | "chainId" ? K_1 : undefined; }>> extends string ? viem.TransactionSerializableLegacy : never) | (viem.ValueOf<Required<{ [K_2 in keyof request]: K_2 extends keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "legacy"> ? K_2 : undefined; }>> extends string ? viem.TransactionRequestLegacy : never) ? "legacy" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: undefined;
        maxFeePerBlobGas?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & (viem.OneOf<{
        maxFeePerGas: viem.FeeValuesEIP1559["maxFeePerGas"];
    } | {
        maxPriorityFeePerGas: viem.FeeValuesEIP1559["maxPriorityFeePerGas"];
    }, viem.FeeValuesEIP1559> & {
        accessList?: viem.TransactionSerializableEIP2930["accessList"] | undefined;
    })) | (viem.ValueOf<Required<{ [K_3 in keyof request]: K_3 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_3 : undefined; }>> extends string ? viem.TransactionSerializableEIP1559 : never) | (viem.ValueOf<Required<{ [K_4 in keyof request]: K_4 extends "accessList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip1559"> ? K_4 : undefined; }>> extends string ? viem.TransactionRequestEIP1559 : never) ? "eip1559" : never) | (request extends ({
        accessList?: viem.AccessList | undefined;
        authorizationList?: undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        gasPrice?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesLegacy> & {
        accessList: viem.TransactionSerializableEIP2930["accessList"];
    }) | (viem.ValueOf<Required<{ [K_5 in keyof request]: K_5 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_5 : undefined; }>> extends string ? viem.TransactionSerializableEIP2930 : never) | (viem.ValueOf<Required<{ [K_6 in keyof request]: K_6 extends "accessList" | keyof viem.FeeValuesLegacy<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip2930"> ? K_6 : undefined; }>> extends string ? viem.TransactionRequestEIP2930 : never) ? "eip2930" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: undefined;
        blobs?: readonly `0x${string}`[] | readonly Uint8Array[] | undefined;
        blobVersionedHashes?: readonly `0x${string}`[] | undefined;
        maxFeePerBlobGas?: bigint | undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: false | readonly viem.BlobSidecar<`0x${string}`>[] | undefined;
    } & (viem.ExactPartial<viem.FeeValuesEIP4844> & viem.OneOf<{
        blobs: viem.TransactionSerializableEIP4844["blobs"];
    } | {
        blobVersionedHashes: viem.TransactionSerializableEIP4844["blobVersionedHashes"];
    } | {
        sidecars: viem.TransactionSerializableEIP4844["sidecars"];
    }, viem.TransactionSerializableEIP4844>)) | (viem.ValueOf<Required<{ [K_7 in keyof request]: K_7 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" | "r" | "s" | "v" | "yParity" | "chainId" ? K_7 : undefined; }>> extends string ? viem.TransactionSerializableEIP4844 : never) | (viem.ValueOf<Required<{ [K_8 in keyof request]: K_8 extends "value" | "nonce" | "type" | "to" | "data" | "from" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "blobs" | "blobVersionedHashes" | "kzg" | "sidecars" ? K_8 : undefined; }>> extends string ? viem.TransactionRequestEIP4844 : never) ? "eip4844" : never) | (request extends ({
        accessList?: undefined;
        authorizationList?: viem_experimental.SignedAuthorizationList | undefined;
        blobs?: undefined;
        blobVersionedHashes?: undefined;
        maxFeePerGas?: bigint | undefined;
        maxPriorityFeePerGas?: bigint | undefined;
        sidecars?: undefined;
    } & viem.ExactPartial<viem.FeeValuesEIP1559> & {
        authorizationList: viem.TransactionSerializableEIP7702["authorizationList"];
    }) | (viem.ValueOf<Required<{ [K_9 in keyof request]: K_9 extends "value" | "nonce" | "type" | "to" | "data" | "gas" | "maxFeePerBlobGas" | "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" | "accessList" | "authorizationList" | "r" | "s" | "v" | "yParity" | "chainId" ? K_9 : undefined; }>> extends string ? viem.TransactionSerializableEIP7702 : never) | (viem.ValueOf<Required<{ [K_10 in keyof request]: K_10 extends "accessList" | "authorizationList" | keyof viem.FeeValuesEIP1559<bigint> | keyof viem.TransactionRequestBase<bigint, number, "eip7702"> ? K_10 : undefined; }>> extends string ? viem.TransactionRequestEIP7702 : never) ? "eip7702" : never) | (request["type"] extends string | undefined ? Extract<request["type"], string> : never)>) ? T_8 extends "eip7702" ? viem.TransactionRequestEIP7702 : never : never : never)>> & {
        chainId?: number | undefined;
    }, (request["parameters"] extends readonly viem.PrepareTransactionRequestParameterType[] ? request["parameters"][number] : "nonce" | "type" | "gas" | "blobVersionedHashes" | "fees" | "chainId") extends infer T_9 ? T_9 extends (request["parameters"] extends readonly viem.PrepareTransactionRequestParameterType[] ? request["parameters"][number] : "nonce" | "type" | "gas" | "blobVersionedHashes" | "fees" | "chainId") ? T_9 extends "fees" ? "gasPrice" | "maxFeePerGas" | "maxPriorityFeePerGas" : T_9 : never : never> & (unknown extends request["kzg"] ? {} : Pick<request, "kzg">))[K]; } : never>;
    requestAddresses: () => Promise<viem.RequestAddressesReturnType>;
    requestPermissions: (args: viem.RequestPermissionsParameters) => Promise<viem.RequestPermissionsReturnType>;
    sendRawTransaction: (args: viem.SendRawTransactionParameters) => Promise<viem.SendRawTransactionReturnType>;
    sendTransaction: <const request extends viem.SendTransactionRequest<TChain, chainOverride>, chainOverride extends Chain | undefined = undefined>(args: viem.SendTransactionParameters<TChain, undefined, chainOverride, request>) => Promise<viem.SendTransactionReturnType>;
    signMessage: (args: viem.SignMessageParameters<undefined>) => Promise<viem.SignMessageReturnType>;
    signTransaction: <chainOverride extends Chain | undefined>(args: viem.SignTransactionParameters<TChain, undefined, chainOverride>) => Promise<viem.SignTransactionReturnType>;
    signTypedData: <const typedData extends {
        [x: string]: readonly abitype.TypedDataParameter[];
        [x: `string[${string}]`]: undefined;
        [x: `function[${string}]`]: undefined;
        [x: `address[${string}]`]: undefined;
        [x: `bool[${string}]`]: undefined;
        [x: `bytes[${string}]`]: undefined;
        [x: `bytes1[${string}]`]: undefined;
        [x: `bytes32[${string}]`]: undefined;
        [x: `bytes31[${string}]`]: undefined;
        [x: `bytes30[${string}]`]: undefined;
        [x: `bytes29[${string}]`]: undefined;
        [x: `bytes28[${string}]`]: undefined;
        [x: `bytes27[${string}]`]: undefined;
        [x: `bytes26[${string}]`]: undefined;
        [x: `bytes25[${string}]`]: undefined;
        [x: `bytes24[${string}]`]: undefined;
        [x: `bytes23[${string}]`]: undefined;
        [x: `bytes22[${string}]`]: undefined;
        [x: `bytes21[${string}]`]: undefined;
        [x: `bytes20[${string}]`]: undefined;
        [x: `bytes19[${string}]`]: undefined;
        [x: `bytes2[${string}]`]: undefined;
        [x: `bytes18[${string}]`]: undefined;
        [x: `bytes17[${string}]`]: undefined;
        [x: `bytes16[${string}]`]: undefined;
        [x: `bytes15[${string}]`]: undefined;
        [x: `bytes14[${string}]`]: undefined;
        [x: `bytes13[${string}]`]: undefined;
        [x: `bytes12[${string}]`]: undefined;
        [x: `bytes11[${string}]`]: undefined;
        [x: `bytes10[${string}]`]: undefined;
        [x: `bytes9[${string}]`]: undefined;
        [x: `bytes8[${string}]`]: undefined;
        [x: `bytes7[${string}]`]: undefined;
        [x: `bytes6[${string}]`]: undefined;
        [x: `bytes5[${string}]`]: undefined;
        [x: `bytes4[${string}]`]: undefined;
        [x: `bytes3[${string}]`]: undefined;
        [x: `int[${string}]`]: undefined;
        [x: `int40[${string}]`]: undefined;
        [x: `int32[${string}]`]: undefined;
        [x: `int24[${string}]`]: undefined;
        [x: `int16[${string}]`]: undefined;
        [x: `int8[${string}]`]: undefined;
        [x: `int48[${string}]`]: undefined;
        [x: `int56[${string}]`]: undefined;
        [x: `int64[${string}]`]: undefined;
        [x: `int72[${string}]`]: undefined;
        [x: `int80[${string}]`]: undefined;
        [x: `int88[${string}]`]: undefined;
        [x: `int96[${string}]`]: undefined;
        [x: `int104[${string}]`]: undefined;
        [x: `int112[${string}]`]: undefined;
        [x: `int120[${string}]`]: undefined;
        [x: `int128[${string}]`]: undefined;
        [x: `int136[${string}]`]: undefined;
        [x: `int144[${string}]`]: undefined;
        [x: `int152[${string}]`]: undefined;
        [x: `int160[${string}]`]: undefined;
        [x: `int168[${string}]`]: undefined;
        [x: `int176[${string}]`]: undefined;
        [x: `int184[${string}]`]: undefined;
        [x: `int192[${string}]`]: undefined;
        [x: `int200[${string}]`]: undefined;
        [x: `int208[${string}]`]: undefined;
        [x: `int216[${string}]`]: undefined;
        [x: `int224[${string}]`]: undefined;
        [x: `int232[${string}]`]: undefined;
        [x: `int240[${string}]`]: undefined;
        [x: `int248[${string}]`]: undefined;
        [x: `int256[${string}]`]: undefined;
        [x: `uint[${string}]`]: undefined;
        [x: `uint40[${string}]`]: undefined;
        [x: `uint32[${string}]`]: undefined;
        [x: `uint24[${string}]`]: undefined;
        [x: `uint16[${string}]`]: undefined;
        [x: `uint8[${string}]`]: undefined;
        [x: `uint48[${string}]`]: undefined;
        [x: `uint56[${string}]`]: undefined;
        [x: `uint64[${string}]`]: undefined;
        [x: `uint72[${string}]`]: undefined;
        [x: `uint80[${string}]`]: undefined;
        [x: `uint88[${string}]`]: undefined;
        [x: `uint96[${string}]`]: undefined;
        [x: `uint104[${string}]`]: undefined;
        [x: `uint112[${string}]`]: undefined;
        [x: `uint120[${string}]`]: undefined;
        [x: `uint128[${string}]`]: undefined;
        [x: `uint136[${string}]`]: undefined;
        [x: `uint144[${string}]`]: undefined;
        [x: `uint152[${string}]`]: undefined;
        [x: `uint160[${string}]`]: undefined;
        [x: `uint168[${string}]`]: undefined;
        [x: `uint176[${string}]`]: undefined;
        [x: `uint184[${string}]`]: undefined;
        [x: `uint192[${string}]`]: undefined;
        [x: `uint200[${string}]`]: undefined;
        [x: `uint208[${string}]`]: undefined;
        [x: `uint216[${string}]`]: undefined;
        [x: `uint224[${string}]`]: undefined;
        [x: `uint232[${string}]`]: undefined;
        [x: `uint240[${string}]`]: undefined;
        [x: `uint248[${string}]`]: undefined;
        [x: `uint256[${string}]`]: undefined;
        string?: undefined;
        address?: undefined;
        bool?: undefined;
        bytes?: undefined;
        bytes1?: undefined;
        bytes32?: undefined;
        bytes31?: undefined;
        bytes30?: undefined;
        bytes29?: undefined;
        bytes28?: undefined;
        bytes27?: undefined;
        bytes26?: undefined;
        bytes25?: undefined;
        bytes24?: undefined;
        bytes23?: undefined;
        bytes22?: undefined;
        bytes21?: undefined;
        bytes20?: undefined;
        bytes19?: undefined;
        bytes2?: undefined;
        bytes18?: undefined;
        bytes17?: undefined;
        bytes16?: undefined;
        bytes15?: undefined;
        bytes14?: undefined;
        bytes13?: undefined;
        bytes12?: undefined;
        bytes11?: undefined;
        bytes10?: undefined;
        bytes9?: undefined;
        bytes8?: undefined;
        bytes7?: undefined;
        bytes6?: undefined;
        bytes5?: undefined;
        bytes4?: undefined;
        bytes3?: undefined;
        int40?: undefined;
        int32?: undefined;
        int24?: undefined;
        int16?: undefined;
        int8?: undefined;
        int48?: undefined;
        int56?: undefined;
        int64?: undefined;
        int72?: undefined;
        int80?: undefined;
        int88?: undefined;
        int96?: undefined;
        int104?: undefined;
        int112?: undefined;
        int120?: undefined;
        int128?: undefined;
        int136?: undefined;
        int144?: undefined;
        int152?: undefined;
        int160?: undefined;
        int168?: undefined;
        int176?: undefined;
        int184?: undefined;
        int192?: undefined;
        int200?: undefined;
        int208?: undefined;
        int216?: undefined;
        int224?: undefined;
        int232?: undefined;
        int240?: undefined;
        int248?: undefined;
        int256?: undefined;
        uint40?: undefined;
        uint32?: undefined;
        uint24?: undefined;
        uint16?: undefined;
        uint8?: undefined;
        uint48?: undefined;
        uint56?: undefined;
        uint64?: undefined;
        uint72?: undefined;
        uint80?: undefined;
        uint88?: undefined;
        uint96?: undefined;
        uint104?: undefined;
        uint112?: undefined;
        uint120?: undefined;
        uint128?: undefined;
        uint136?: undefined;
        uint144?: undefined;
        uint152?: undefined;
        uint160?: undefined;
        uint168?: undefined;
        uint176?: undefined;
        uint184?: undefined;
        uint192?: undefined;
        uint200?: undefined;
        uint208?: undefined;
        uint216?: undefined;
        uint224?: undefined;
        uint232?: undefined;
        uint240?: undefined;
        uint248?: undefined;
        uint256?: undefined;
    } | {
        [key: string]: unknown;
    }, primaryType extends string>(args: viem.SignTypedDataParameters<typedData, primaryType, undefined>) => Promise<viem.SignTypedDataReturnType>;
    switchChain: (args: viem.SwitchChainParameters) => Promise<void>;
    watchAsset: (args: viem.WatchAssetParameters) => Promise<viem.WatchAssetReturnType>;
    writeContract: <const abi extends abitype.Abi | readonly unknown[], functionName extends viem.ContractFunctionName<abi, "nonpayable" | "payable">, args_1 extends viem.ContractFunctionArgs<abi, "nonpayable" | "payable", functionName>, chainOverride extends Chain | undefined = undefined>(args: viem.WriteContractParameters<abi, functionName, args_1, TChain, undefined, chainOverride>) => Promise<viem.WriteContractReturnType>;
    extend: <const client extends {
        [x: string]: unknown;
        account?: undefined;
        batch?: undefined;
        cacheTime?: undefined;
        ccipRead?: undefined;
        chain?: undefined;
        key?: undefined;
        name?: undefined;
        pollingInterval?: undefined;
        request?: undefined;
        transport?: undefined;
        type?: undefined;
        uid?: undefined;
    } & viem.ExactPartial<Pick<viem.PublicActions<HttpTransport, TChain, undefined>, "call" | "createContractEventFilter" | "createEventFilter" | "estimateContractGas" | "estimateGas" | "getBlock" | "getBlockNumber" | "getChainId" | "getContractEvents" | "getEnsText" | "getFilterChanges" | "getGasPrice" | "getLogs" | "getTransaction" | "getTransactionCount" | "getTransactionReceipt" | "prepareTransactionRequest" | "readContract" | "sendRawTransaction" | "simulateContract" | "uninstallFilter" | "watchBlockNumber" | "watchContractEvent"> & Pick<viem.WalletActions<TChain, undefined>, "sendTransaction" | "writeContract">>>(fn: (client: viem.Client<HttpTransport, TChain, undefined, TRpcSchema extends RpcSchema ? [{
        Method: "eth_accounts";
        Parameters?: undefined;
        ReturnType: Address[];
    }, {
        Method: "eth_chainId";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_estimateGas";
        Parameters: [transaction: viem.RpcTransactionRequest] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag, stateOverride: viem.RpcStateOverride];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_requestAccounts";
        Parameters?: undefined;
        ReturnType: Address[];
    }, {
        Method: "eth_sendTransaction";
        Parameters: [transaction: viem.RpcTransactionRequest];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_sendRawTransaction";
        Parameters: [signedTransaction: viem.Hex];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_sign";
        Parameters: [address: Address, data: viem.Hex];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_signTransaction";
        Parameters: [request: viem.RpcTransactionRequest];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_signTypedData_v4";
        Parameters: [address: Address, message: string];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_syncing";
        Parameters?: undefined;
        ReturnType: viem.NetworkSync | false;
    }, {
        Method: "personal_sign";
        Parameters: [data: viem.Hex, address: Address];
        ReturnType: viem.Hex;
    }, {
        Method: "wallet_addEthereumChain";
        Parameters: [chain: viem.AddEthereumChainParameter];
        ReturnType: null;
    }, {
        Method: "wallet_getCallsStatus";
        Parameters?: [string];
        ReturnType: viem.WalletGetCallsStatusReturnType;
    }, {
        Method: "wallet_getCapabilities";
        Parameters?: [Address];
        ReturnType: {
            [x: `0x${string}`]: viem.WalletCapabilities;
        };
    }, {
        Method: "wallet_getPermissions";
        Parameters?: undefined;
        ReturnType: viem.WalletPermission[];
    }, {
        Method: "wallet_grantPermissions";
        Parameters?: [viem.WalletGrantPermissionsParameters];
        ReturnType: Prettify<viem.WalletGrantPermissionsReturnType>;
    }, {
        Method: "wallet_requestPermissions";
        Parameters: [permissions: {
            eth_accounts: Record<string, any>;
        }];
        ReturnType: viem.WalletPermission[];
    }, {
        Method: "wallet_revokePermissions";
        Parameters: [permissions: {
            eth_accounts: Record<string, any>;
        }];
        ReturnType: null;
    }, {
        Method: "wallet_sendCalls";
        Parameters?: viem.WalletSendCallsParameters;
        ReturnType: string;
    }, {
        Method: "wallet_showCallsStatus";
        Parameters?: [string];
        ReturnType: void;
    }, {
        Method: "wallet_switchEthereumChain";
        Parameters: [chain: {
            chainId: string;
        }];
        ReturnType: null;
    }, {
        Method: "wallet_watchAsset";
        Parameters: viem.WatchAssetParams;
        ReturnType: boolean;
    }, ...TRpcSchema] : viem.WalletRpcSchema, viem.WalletActions<TChain, undefined>>) => client) => viem.Client<HttpTransport, TChain, undefined, TRpcSchema extends RpcSchema ? [{
        Method: "eth_accounts";
        Parameters?: undefined;
        ReturnType: Address[];
    }, {
        Method: "eth_chainId";
        Parameters?: undefined;
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_estimateGas";
        Parameters: [transaction: viem.RpcTransactionRequest] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag] | [transaction: viem.RpcTransactionRequest, block: viem.RpcBlockNumber | viem.BlockTag, stateOverride: viem.RpcStateOverride];
        ReturnType: viem.Quantity;
    }, {
        Method: "eth_requestAccounts";
        Parameters?: undefined;
        ReturnType: Address[];
    }, {
        Method: "eth_sendTransaction";
        Parameters: [transaction: viem.RpcTransactionRequest];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_sendRawTransaction";
        Parameters: [signedTransaction: viem.Hex];
        ReturnType: viem.Hash;
    }, {
        Method: "eth_sign";
        Parameters: [address: Address, data: viem.Hex];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_signTransaction";
        Parameters: [request: viem.RpcTransactionRequest];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_signTypedData_v4";
        Parameters: [address: Address, message: string];
        ReturnType: viem.Hex;
    }, {
        Method: "eth_syncing";
        Parameters?: undefined;
        ReturnType: viem.NetworkSync | false;
    }, {
        Method: "personal_sign";
        Parameters: [data: viem.Hex, address: Address];
        ReturnType: viem.Hex;
    }, {
        Method: "wallet_addEthereumChain";
        Parameters: [chain: viem.AddEthereumChainParameter];
        ReturnType: null;
    }, {
        Method: "wallet_getCallsStatus";
        Parameters?: [string];
        ReturnType: viem.WalletGetCallsStatusReturnType;
    }, {
        Method: "wallet_getCapabilities";
        Parameters?: [Address];
        ReturnType: {
            [x: `0x${string}`]: viem.WalletCapabilities;
        };
    }, {
        Method: "wallet_getPermissions";
        Parameters?: undefined;
        ReturnType: viem.WalletPermission[];
    }, {
        Method: "wallet_grantPermissions";
        Parameters?: [viem.WalletGrantPermissionsParameters];
        ReturnType: Prettify<viem.WalletGrantPermissionsReturnType>;
    }, {
        Method: "wallet_requestPermissions";
        Parameters: [permissions: {
            eth_accounts: Record<string, any>;
        }];
        ReturnType: viem.WalletPermission[];
    }, {
        Method: "wallet_revokePermissions";
        Parameters: [permissions: {
            eth_accounts: Record<string, any>;
        }];
        ReturnType: null;
    }, {
        Method: "wallet_sendCalls";
        Parameters?: viem.WalletSendCallsParameters;
        ReturnType: string;
    }, {
        Method: "wallet_showCallsStatus";
        Parameters?: [string];
        ReturnType: void;
    }, {
        Method: "wallet_switchEthereumChain";
        Parameters: [chain: {
            chainId: string;
        }];
        ReturnType: null;
    }, {
        Method: "wallet_watchAsset";
        Parameters: viem.WatchAssetParams;
        ReturnType: boolean;
    }, ...TRpcSchema] : viem.WalletRpcSchema, { [K in keyof client]: client[K]; } & viem.WalletActions<TChain, undefined>>;
};

/**
 * Configuration type for Web3Modal
 */
type Web3ModalConfig = Parameters<typeof createWeb3Modal>["0"];
/**
 * Limited configuration type for Web3Modal, excluding certain properties
 */
type LimitedWeb3ModalConfig = Prettify<Omit<Web3ModalConfig, "chains" | "wagmiConfig" | "metadata" | "projectId"> & {
    metadata: Omit<NonNullable<Web3ModalConfig["metadata"]>, "url">;
}>;
/**
 * Parameters for configuring Wagmi
 */
type WagmiConfigParameters = Prettify<{
    chain: Chain;
    wagmiConfig?: Partial<Omit<Parameters<typeof defaultWagmiConfig>[0], "client">> & {
        transportConfig?: TransportConfig<"http">;
    };
    web3ModalConfig?: LimitedWeb3ModalConfig;
}>;
/**
 * Configuration type for Wagmi, excluding the chain property
 */
type WagmiConfig = Prettify<Omit<WagmiConfigParameters, "chain">>;

type GraphQLClientType = "portal" | "thegraph" | "hasura";
/**
 * Creates a GraphQL client for the specified type.
 *
 * This function generates a new GraphQL client instance based on the provided client type.
 * It uses the NEXT_PUBLIC_SETTLEMINT_APP_URL environment variable to construct the GraphQL endpoint URL.
 *
 * @param type - The type of GraphQL client to create.
 * @returns A new GraphQL client instance.
 * @throws {Error} If an invalid GraphQL client type is provided.
 * @throws {Error} If the NEXT_PUBLIC_SETTLEMINT_APP_URL environment variable is not defined.
 *
 * @example
 * ```typescript
 * const portalClient = createGraphqlClient('portal');
 * const thegraphClient = createGraphqlClient('thegraph');
 * const hasuraClient = createGraphqlClient('hasura');
 * ```
 */
declare function createGraphqlClient(type: GraphQLClientType): GraphQLClient;

/**
 * Creates a portal client for interacting with the SettleMint API.
 *
 * This function generates a client instance that can be used to make API requests
 * to the SettleMint portal. It uses the NEXT_PUBLIC_SETTLEMINT_APP_URL environment
 * variable to construct the base URL for the API endpoints.
 *
 * @template PortalRestPaths - The type representing the API paths and operations.
 * @returns A client instance for making API requests.
 * @throws {Error} If NEXT_PUBLIC_SETTLEMINT_APP_URL is not defined in the environment.
 *
 * @example
 * ```typescript
 * type MyApiPaths = {
 *   '/users': {
 *     get: {
 *       responses: {
 *         200: { content: { 'application/json': User[] } }
 *       }
 *     }
 *   }
 * };
 *
 * const client = createPortalRestClient<MyApiPaths>();
 * const { data, error } = await client.GET('/users');
 * ```
 */
declare function createPortalRestClient<PortalRestPaths extends {}>(): ReturnType<typeof createClient<PortalRestPaths>>;

/**
 * A collection of functions for generating various SDK components.
 *
 * This object provides methods to create clients and configurations for interacting with
 * different parts of the SettleMint ecosystem, including REST APIs, GraphQL endpoints,
 * blockchain interactions, and React hooks for Web3 functionality.
 *
 * @example
 * ```typescript
 * const portalClient = sdkGenerator.createPortalRestClient();
 * const graphqlClient = sdkGenerator.createGraphqlClient('portal');
 * const viemPublicClient = sdkGenerator.createViemPublicClient({ chain: mainnet });
 * const viemWalletClient = sdkGenerator.createViemWalletClient({ chain: mainnet });
 * const { wagmiConfig, web3ModalConfig } = sdkGenerator.createWagmiConfig({ chain: mainnet });
 * ```
 */
declare const sdkGenerator: {
    readonly createPortalRestClient: typeof createPortalRestClient;
    readonly createGraphqlClient: typeof createGraphqlClient;
    readonly createViemPublicClient: typeof createViemPublicClient;
    readonly createViemWalletClient: typeof createViemWalletClient;
    readonly createWagmiConfig: (parameters: WagmiConfigParameters) => {
        wagmiConfig: wagmi.Config;
        web3ModalConfig: Web3ModalConfig;
    };
};

export { SettleMintProvider, type ViemConfig, type WagmiConfig, sdkGenerator };
